@@ -5,7 +5,6 @@ from shutil import rmtree
 
 import torch
 from torch import nn
-from torch.optim import AdamW, Adam
 import numpy as np
 
 from PIL import Image
@@ -16,6 +15,7 @@ from torchvision.utils import make_grid, save_image
 
 from einops import rearrange
 from nuwa_pytorch.nuwa_pytorch import VQGanVAE
+from nuwa_pytorch.optimizer import get_optimizer
 
 # helpers
 
@@ -43,35 +43,6 @@ def accum_log(log, new_logs):
         log[key] = old_value + new_value
     return log
 
-# adamw functions
-
-def separate_weight_decayable_params(params):
-    no_wd_params = set([param for param in params if param.ndim < 2])
-    wd_params = set(params) - no_wd_params
-    return wd_params, no_wd_params
-
-def get_optimizer(
-    params,
-    lr = 3e-4,
-    wd = 1e-1,
-    filter_by_requires_grad = False
-):
-    if filter_by_requires_grad:
-        params = list(filter(lambda t: t.requires_grad, params))
-
-    if wd == 0:
-        return Adam(list(params), lr = lr)
-
-    params = set(params)
-    wd_params, no_wd_params = separate_weight_decayable_params(params)
-
-    param_groups = [
-        {'params': list(wd_params)},
-        {'params': list(no_wd_params), 'weight_decay': 0},
-    ]
-
-    return AdamW(param_groups, lr = lr, weight_decay = wd)
-
 # classes
 
 class MemmappedImageDataset(Dataset):
